@@ -25,8 +25,10 @@ $Id: dvdpreferences.cpp,v 1.3 2003/05/08 03:22:25 sander Exp $
 extern "C" {
 #include <ogle/dvdcontrol.h>
 }
+#include "dvdapp.h"
 #include "dvdwindow.h"
 #include "dvddxr3.h"
+#include "dvdxv.h"
 #include "dvddesktop.h"
 
 
@@ -36,6 +38,8 @@ extern "C" {
 // Options Dialog -  FIXME
 //----------------------------------------------------------------------------------
 long DVDWindow::onCmdOptions(FXObject*,FXSelector,void*){
+  DVDApp * dvdapp = dynamic_cast<DVDApp*>(getApp());
+
   const FXuint listboxstyle=LISTBOX_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_FILL_COLUMN|LAYOUT_CENTER_Y;
   const FXuint labelstyle=LAYOUT_CENTER_Y|LABEL_NORMAL|LAYOUT_RIGHT;
   const FXuint textfieldstyle=TEXTFIELD_ENTER_ONLY|LAYOUT_FILL_X|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_COLUMN;
@@ -50,6 +54,8 @@ long DVDWindow::onCmdOptions(FXObject*,FXSelector,void*){
   FXDataTarget target_start_dvd(start_dvd);
 
   FXDataTarget target_auto_bookmark(auto_bookmark);
+  FXDataTarget target_play_bookmark(play_last_session);
+
   FXDataTarget target_auto_show(auto_show);
   FXDataTarget target_dvdroot(dvdroot);
   FXDataTarget target_auto_disable(auto_disable);
@@ -68,7 +74,7 @@ long DVDWindow::onCmdOptions(FXObject*,FXSelector,void*){
   FXGroupBox * grpbox;
   FXMatrix   * matrix;
   FXTextField *txtfld;
-
+  FXVerticalFrame * vframe;
 
   /// GOGGLES SETTINGS PANEL
   /// ======================
@@ -80,15 +86,29 @@ long DVDWindow::onCmdOptions(FXObject*,FXSelector,void*){
 
   //  new FXCheckButton(main,"Open DVD on start up",&target_start_dvd,FXDataTarget::ID_VALUE);
 //  new FXCheckButton(frame1,"Fullscreen on start up",&target_start_fullscreen,FXDataTarget::ID_VALUE);
-  new FXCheckButton(frame1,"Auto play DVD on startup.",&target_start_dvd,FXDataTarget::ID_VALUE);
-  new FXCheckButton(frame1,"Auto show controls on fullscreen.",&target_auto_show,FXDataTarget::ID_VALUE);
-  new FXCheckButton(frame1,"Auto disable Menus.",&target_auto_disable,FXDataTarget::ID_VALUE);
-  new FXCheckButton(frame1,"Auto Bookmark",&target_auto_bookmark,FXDataTarget::ID_VALUE);
-  new FXCheckButton(frame1,"Disable Screensaver",&target_screensaver,FXDataTarget::ID_VALUE);
-  FXCheckButton * check=new FXCheckButton(frame1,"Disable Power Management",&target_dpms,FXDataTarget::ID_VALUE);
-  new FXCheckButton(frame1,"Screenshots with subtitles",&target_screenshot,FXDataTarget::ID_VALUE);
-  new FXCheckButton(frame1,"Filter Subpicture Menu [Ogle Bug Fix]",&target_subpic_filter,FXDataTarget::ID_VALUE);
-  new FXCheckButton(frame1,"Select first Audiostream if none is active [Ogle Bug Fix]",&target_audiostream,FXDataTarget::ID_VALUE);
+
+
+  grpbox =  new FXGroupBox(frame1,"Features",FRAME_RIDGE|LAYOUT_FILL_X);
+
+
+  new FXCheckButton(grpbox,"Auto Play - Automatically play dvd when Goggles starts.",&target_start_dvd,FXDataTarget::ID_VALUE);
+  new FXCheckButton(grpbox,"Auto Raise - Show Goggles window when toggling fullscreen mode.",&target_auto_show,FXDataTarget::ID_VALUE);
+  new FXCheckButton(grpbox,"Disable Menus - Disable menus if DVD asks for it.",&target_auto_disable,FXDataTarget::ID_VALUE);
+
+  new FXCheckButton(grpbox,"Save Last Session  - When quiting Goggles save session.",&target_auto_bookmark,FXDataTarget::ID_VALUE);
+  new FXCheckButton(grpbox,"Play Last Session  - Automatically play last session.",&target_play_bookmark,FXDataTarget::ID_VALUE);
+
+  new FXCheckButton(grpbox,"Save Screenshots with subtitles.",&target_screenshot,FXDataTarget::ID_VALUE);
+
+
+  grpbox =  new FXGroupBox(frame1,"Power Management / Screensaver",FRAME_RIDGE|LAYOUT_FILL_X);
+  new FXCheckButton(grpbox,"Disable Screensaver.",&target_screensaver,FXDataTarget::ID_VALUE);
+  FXCheckButton * check=new FXCheckButton(grpbox,"Disable Power Management.",&target_dpms,FXDataTarget::ID_VALUE);
+
+  grpbox =  new FXGroupBox(frame1,"Ogle Bugfixes/Workarounds",FRAME_RIDGE|LAYOUT_FILL_X);
+
+  new FXCheckButton(grpbox,"Filter Subpicture Menu - do not show empty entries.",&target_subpic_filter,FXDataTarget::ID_VALUE);
+  new FXCheckButton(grpbox,"Always activate audiostream - if none is active, select first available.",&target_audiostream,FXDataTarget::ID_VALUE);
 
   if (!dpms_manager->isAvailable()){
     check->disable();
@@ -238,23 +258,101 @@ long DVDWindow::onCmdOptions(FXObject*,FXSelector,void*){
 
 
 
-#ifdef HAVE_XVIDEO
+#ifdef HAVE_XV
 
   /// XVIDEO SETTINGS PANEL
   /// ======================
-
-  new FXTabItem(tabbook," &XVideo ",NULL);
-  FXHorizontalFrame * frame4= new FXHorizontalFrame(tabbook,FRAME_THICK|FRAME_RAISED);
+  FXCheckButton * chck;
+  FXHorizontalFrame * hfr; 
+  FXSlider * slider;
+  FXButton * button;
+  XVAdaptor * adaptor;
 
 
-  FXGroupBox * box4 = new FXGroupBox(frame4,"Video Control",LAYOUT_FILL_X|FRAME_RIDGE);
-  FXMatrix * mat4=new FXMatrix(box4,5,MATRIX_BY_ROWS|LAYOUT_FILL_X|LAYOUT_FILL_Y);
 
-  new FXLabel(mat4,"Brightness");
-  new FXLabel(mat4,"Contrast");
-  new FXLabel(mat4,"Saturation");
-  new FXLabel(mat4,"Hue");
-  new FXLabel(mat4,"Colorkey");
+  if (dvdapp->getXVControl()->getNumAdaptors()>0) {
+
+    new FXTabItem(tabbook," &XVideo ",NULL);
+    vframe= new FXVerticalFrame(tabbook,FRAME_THICK|FRAME_RAISED|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+
+    new FXLabel(vframe,FXStringFormat("XVideo v%d.%d",dvdapp->getXVControl()->getVersion(),dvdapp->getXVControl()->getRelease()),NULL,FRAME_SUNKEN|LAYOUT_FILL_X);
+  
+    matrix=new FXMatrix(vframe,2,MATRIX_BY_COLUMNS|LAYOUT_FILL_X,0,0,0,0,0,0,0,0);
+    new FXLabel(matrix,"Configure Adaptor: ",NULL,labelstyle);
+    FXListBox * adaptorlist = new FXListBox(matrix,4,NULL,0,listboxstyle);
+
+    FXSwitcher * switcher = new FXSwitcher(vframe,LAYOUT_FILL_X|LAYOUT_FILL_Y);
+
+    for (FXint i=0;i<dvdapp->getXVControl()->getNumAdaptors();i++){
+      adaptor = dvdapp->getXVControl()->getAdaptor(i);
+      adaptorlist->appendItem(adaptor->getName());
+      FXVerticalFrame * vframe2 = new FXVerticalFrame(switcher,LAYOUT_FILL_X,0,0,0,0,0,0,0,0);
+    
+      if (adaptor->getNumColorProperties() && adaptor->getNumCheckProperties()) {
+        hfr    = new FXHorizontalFrame(vframe2,LAYOUT_FILL_X|PACK_UNIFORM_HEIGHT,0,0,0,0,0,0,0,0);        
+        grpbox = new FXGroupBox(hfr,"",FRAME_RIDGE|LAYOUT_FILL_X);      
+
+        for (FXint j=0;j<adaptor->getNumCheckProperties();j++){
+          chck = new FXCheckButton(grpbox,adaptor->getCheckProperty(j)->name,adaptor->getCheckProperty(j),XVProperty::ID_CHECK_PROPERTY);
+          }
+
+        grpbox=new FXGroupBox(hfr,"",FRAME_RIDGE|LAYOUT_FILL_X);
+        matrix=new FXMatrix(grpbox,2,MATRIX_BY_COLUMNS|LAYOUT_FILL_X,0,0,0,0,0,0,0,0);
+
+        for (FXint j=0;j<adaptor->getNumColorProperties();j++){
+          FXColorWell * well = new FXColorWell(matrix,0,adaptor->getColorProperty(j),XVProperty::ID_COLOR_PROPERTY);
+          new FXLabel(matrix,adaptor->getColorProperty(j)->name,NULL,ICON_BEFORE_TEXT|JUSTIFY_RIGHT|LAYOUT_CENTER_Y);
+          }
+        }
+      else {
+        if (adaptor->getNumCheckProperties()){
+          grpbox = new FXGroupBox(vframe2,"",FRAME_RIDGE|LAYOUT_FILL_X);      
+
+          for (FXint j=0;j<adaptor->getNumCheckProperties();j++){
+            chck = new FXCheckButton(grpbox,adaptor->getCheckProperty(j)->name,adaptor->getCheckProperty(j),XVProperty::ID_CHECK_PROPERTY);
+            }
+          }
+        if (adaptor->getNumColorProperties()){
+          grpbox=new FXGroupBox(vframe2,"",FRAME_RIDGE|LAYOUT_FILL_X);
+          matrix=new FXMatrix(grpbox,2,MATRIX_BY_COLUMNS|LAYOUT_FILL_X,0,0,0,0,0,0,0,0);
+
+          for (FXint j=0;j<adaptor->getNumColorProperties();j++){
+            FXColorWell * well = new FXColorWell(matrix,0,adaptor->getColorProperty(j),XVProperty::ID_COLOR_PROPERTY);
+            new FXLabel(matrix,adaptor->getColorProperty(j)->name,NULL,ICON_BEFORE_TEXT|JUSTIFY_RIGHT|LAYOUT_CENTER_Y);
+            }
+          }
+        }
+
+    if (adaptor->getNumValueProperties()){
+      grpbox=new FXGroupBox(vframe2,"",FRAME_RIDGE|LAYOUT_FILL_X);
+      matrix=new FXMatrix(grpbox,3,MATRIX_BY_COLUMNS|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0);
+
+      for (FXint j=0;j<adaptor->getNumValueProperties();j++){
+        new FXLabel(matrix,adaptor->getValueProperty(j)->name,NULL,LABEL_NORMAL|LAYOUT_CENTER_Y|JUSTIFY_LEFT);
+        slider=new FXSlider(matrix,adaptor->getValueProperty(j),XVProperty::ID_SLIDER_PROPERTY,LAYOUT_FILL_X|LAYOUT_FILL_COLUMN|SLIDER_INSIDE_BAR|LAYOUT_CENTER_Y);
+        slider->setRange(adaptor->getValueProperty(j)->min,adaptor->getValueProperty(j)->max);
+        new FXTextField(matrix,5,adaptor->getValueProperty(j),XVProperty::ID_SLIDERTEXT_PROPERTY,TEXTFIELD_NORMAL|LAYOUT_CENTER_Y);
+        }
+      }
+
+    if (adaptor->getNumFunctionProperties()){
+      matrix=new FXMatrix(vframe2,4,MATRIX_BY_COLUMNS|LAYOUT_FILL_X|PACK_UNIFORM_WIDTH,0,0,0,0,0,0,0,0);
+
+      for (FXint j=0;j<adaptor->getNumFunctionProperties();j++){
+        new FXButton(matrix,adaptor->getFunctionProperty(j)->name,NULL,adaptor->getFunctionProperty(j),XVProperty::ID_FUNCTION_PROPERTY,BUTTON_INITIAL|BUTTON_DEFAULT|LAYOUT_RIGHT|FRAME_RAISED|FRAME_THICK,0,0,0,0,20,20);
+        }
+      }
+    }
+  adaptorlist->setNumVisible(dvdapp->getXVControl()->getNumAdaptors());
+  adaptorlist->setTarget(switcher);
+  adaptorlist->setSelector(FXWindow::ID_SETVALUE);  
+  }
+#endif
+
+
+//  new FXSeparator(vframe,LAYOUT_FILL_X|SEPARATOR_GROOVE);
+
+
 
 //  new FXTextField(mat4,5,xvcontrol,ID_XV_BRIGHTNESS);
 //  new FXTextField(mat4,5,xvcontrol,ID_XV_CONTRAST);
@@ -269,7 +367,7 @@ long DVDWindow::onCmdOptions(FXObject*,FXSelector,void*){
  // new FXSlider(mat3,xvcontrol,ID_XV_HUE,LAYOUT_FILL_X|SLIDER_INSIDE_BAR|LAYOUT_FILL_COLUMN|LAYOUT_CENTER_Y);
   //new FXSlider(mat3,xvcontrol,ID_XV_COLORKEY,LAYOUT_FILL_X|SLIDER_INSIDE_BAR|LAYOUT_FILL_COLUMN|LAYOUT_CENTER_Y);
 
-#endif
+//#endif
 
   /// Keyboard Shortcuts PANEL
   /// ======================
