@@ -631,10 +631,10 @@ void DVDWindow::createIcons(){
   icon_bookopen_menu   =new FXPNGIcon(getApp(),&bookopen_png);
   icon_bookclose_menu  =new FXPNGIcon(getApp(),&bookclose_png);
 
-  img_fox         =new FXPNGImage(getApp(),&poweredbyfox_png);
-  img_ogle        =new FXPNGImage(getApp(),&ogle_png);
   img_fifthplanet =new FXPNGImage(getApp(),&fifthplanet_png);
   img_gogglessmall=new FXPNGImage(getApp(),&goggleslogosmall_png);
+  img_goggles     =new FXPNGImage(getApp(),&goggleslogo_png);
+
 
   FXColor basecolor = getApp()->getBaseColor();
   icon_goroot->blend(basecolor);
@@ -657,9 +657,9 @@ void DVDWindow::createIcons(){
 // Destroy Icons
 //----------------------------------------------------------------------------------
 void DVDWindow::deleteIcons(){
-  delete img_fox;
-  delete img_ogle;
   delete img_fifthplanet;
+  delete img_gogglessmall;
+  delete img_goggles;
   delete icon_play;
   delete icon_stop;
   delete icon_pause;
@@ -717,6 +717,8 @@ void DVDWindow::readRegistry(){
   start_dvd=getApp()->reg().readIntEntry("OGLE","autostart",0);
   start_fullscreen=getApp()->reg().readIntEntry("OGLE","startfullscreen",0);
   screenshot_with_spu=getApp()->reg().readIntEntry("OGLE","screenshot_with_spu",0);
+  play_last_session=getApp()->reg().readIntEntry("OGLE","play_last_session",1);
+
 
   // Read in Shortcuts
   getAccelTable()->addAccel(fxparseAccel(getApp()->reg().readStringEntry("HotKeys","Fullscreen",DEFAULT_SHORTCUT_FULLSCREEN)),this,FXSEL(SEL_COMMAND,ID_TOGGLE_FULLSCREEN));
@@ -755,6 +757,7 @@ void DVDWindow::writeRegistry(){
   getApp()->reg().writeIntEntry("OGLE","filtersubpicture",filter_subpicture_entry);
   getApp()->reg().writeIntEntry("OGLE","autoaudiostream",auto_audiostream);
   getApp()->reg().writeIntEntry("OGLE","screenshot_with_spu",screenshot_with_spu);
+  getApp()->reg().writeIntEntry("OGLE","play_last_session",play_last_session);
   }
 
 
@@ -1042,17 +1045,24 @@ long DVDWindow::onCmdPlay(FXObject*sender,FXSelector selector,void* ptr){
 
   DVDResult_t res;
 
-  if (fspeed>1.0 || bspeed>1.0) {
+  if (pause) {
+    DVDPauseOff((DVDNav_t*)navigator);
+    pause=FALSE;
+    }
+
+  if ((fspeed!=1.0) || (bspeed!=1.0)) {
     fspeed=bspeed=1.0;
     DVDForwardScan((DVDNav_t*)navigator,fspeed);
     return 1;
     }
 
+/*
   if (pause) {
     DVDPauseOff((DVDNav_t*)navigator);
     pause=FALSE;
     return 1;
     }
+*/
 
   if (uop&UOP_FLAG_Resume){
     res=DVDResume((DVDNav_t*)navigator);
@@ -1065,7 +1075,7 @@ long DVDWindow::onCmdPlay(FXObject*sender,FXSelector selector,void* ptr){
   }
 
 long DVDWindow::onUpdPlay(FXObject* sender,FXSelector,void*){
-  FXbool enable=(navigator!=NULL) && ( (!dvd_started) || (pause) || (bspeed>1.0) || (fspeed>1.0) || ((dom!=DVD_DOMAIN_VTSTitle) && (uop&UOP_FLAG_Resume)) );
+  FXbool enable=(navigator!=NULL) && ( (!dvd_started) || (pause) || (bspeed!=1.0) || (fspeed!=1.0) || ((dom!=DVD_DOMAIN_VTSTitle) && (uop&UOP_FLAG_Resume)) );
   sender->handle(this,enable?FXSEL(SEL_COMMAND,ID_ENABLE):FXSEL(SEL_COMMAND,ID_DISABLE),NULL);
   return 1;
   }
@@ -1128,7 +1138,7 @@ long DVDWindow::onCmdNext(FXObject*,FXSelector,void*){
   }
 
 long DVDWindow::onUpdNext(FXObject* sender,FXSelector,void*){
-  FXbool enable=((navigator!=NULL) && (uop&UOP_FLAG_NextPGSearch) );
+  FXbool enable=((navigator!=NULL) && (uop&UOP_FLAG_NextPGSearch) && (!pause) );
   sender->handle(this,enable?FXSEL(SEL_COMMAND,ID_ENABLE):FXSEL(SEL_COMMAND,ID_DISABLE),NULL);
   return 1;
   }
@@ -1153,7 +1163,7 @@ long DVDWindow::onCmdPrevious(FXObject*,FXSelector,void*ptr){
   }
 
 long DVDWindow::onUpdPrevious(FXObject* sender,FXSelector,void*){
-  FXbool enable=((navigator!=NULL) && (uop&UOP_FLAG_PrevOrTopPGSearch));
+  FXbool enable=((navigator!=NULL) && (uop&UOP_FLAG_PrevOrTopPGSearch) && (!pause));
   sender->handle(this,enable?FXSEL(SEL_COMMAND,ID_ENABLE):FXSEL(SEL_COMMAND,ID_DISABLE),NULL);
   return 1;
   }
@@ -1165,10 +1175,19 @@ long DVDWindow::onUpdPrevious(FXObject* sender,FXSelector,void*){
 long DVDWindow::onCmdSearchForward(FXObject*,FXSelector,void*){
   if (bspeed > 1.0){
     bspeed-=0.5;
+    pause=FALSE;
     DVDBackwardScan((DVDNav_t*)navigator,bspeed);
     }
   else {
-    fspeed+=0.5;
+//    fspeed+=0.5;
+//    pause=FALSE;
+    if (pause)
+      fspeed=0.0625;
+    else if ((fspeed >= 1.0) && (fspeed < 8.0)) //max speed from dvd_cli
+      fspeed+=0.5;
+    else
+      fspeed*=2;
+    pause=FALSE;
     DVDForwardScan((DVDNav_t*)navigator,fspeed);
     }
   return 1;
@@ -1187,10 +1206,17 @@ long DVDWindow::onUpdSearchForward(FXObject* sender,FXSelector,void*){
 long DVDWindow::onCmdSearchBackward(FXObject*,FXSelector,void*){
   if (fspeed > 1.0) {
     fspeed-=0.5;
+    pause=FALSE;
     DVDForwardScan((DVDNav_t*)navigator,fspeed);
     }
-  else { /// Don't do this yet..
+  else if ((fspeed < 1.0)&&(fspeed > 0.1)){
+    fspeed/=2;
+    pause = FALSE;
+    DVDForwardScan((DVDNav_t*)navigator,fspeed);
+    }
+  else {
 //    bspeed+=0.5;
+//    pause=FALSE;
 //    DVDBackwardScan((DVDNav_t*)navigator,bspeed);
     }
   return 1;
@@ -1467,6 +1493,7 @@ void DVDWindow::initBookmarks(){
     FXchar * extra_appinfo=NULL;
     FXchar * appinfo=NULL;
     FXMenuCommand * command;
+    FXMenuCommand * sessioncommand=NULL;
     bookmark_no=0;
     FXbool autobookmarkfound=FALSE;
 
@@ -1478,6 +1505,7 @@ void DVDWindow::initBookmarks(){
         FXMenuSeparator * separator = new FXMenuSeparator(gotomenu);
         separator->create();
         command = new FXMenuCommand(gotomenu,"R&esume Last Session...",NULL,this,ID_BOOKMARK);
+        sessioncommand=command;
         FXFREE(&extra_appinfo);
         autobook=TRUE;
         autobookmarkfound=TRUE;
@@ -1493,7 +1521,11 @@ void DVDWindow::initBookmarks(){
       FXFREE(&usercomment); 
       FXFREE(&appinfo);
       bookmark_no++;
-
+      }
+    
+    /// Jump to last session
+    if (autobookmarkfound && play_last_session){
+      handle(sessioncommand,FXSEL(SEL_COMMAND,ID_BOOKMARK),NULL);
       }
     }
   }
@@ -2282,16 +2314,25 @@ long DVDWindow::onCmdSelectDirectory(FXObject*,FXSelector selector,void*){
 // About Dialog
 //----------------------------------------------------------------------------------
 long DVDWindow::onCmdAbout(FXObject *,FXSelector,void*){
+  FXVerticalFrame * contents;
   FXDialogBox dialog(this,"About Goggles");
   FXVerticalFrame * main=new FXVerticalFrame(&dialog,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0);
-  FXHorizontalFrame * logoframe=new FXHorizontalFrame(main,LAYOUT_FILL_X|LAYOUT_FILL_Y|PACK_UNIFORM_WIDTH,0,0,0,0,0,0,0,0);
-  new FXImageFrame(logoframe,img_fox,FRAME_SUNKEN);
-  FXImageFrame * frame =new FXImageFrame(logoframe,img_ogle,FRAME_SUNKEN);
-  frame->setBackColor(FXRGB(255,255,255));
-  FXVerticalFrame * textframe=new FXVerticalFrame(main,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0);
-  new FXLabel(textframe,FXStringFormat("Goggles  v%d.%d.%d - %s - %s\nCopyright (C) 2002-2003 Sander Jansen. All Rights Reserved\n\nGoggles uses FOX Toolkit version %d.%d.%d\n%s\n\nOriginal \"Goggles\" Logo designed by Gyurka Jansen\n(http://glas.its.tudelft.nl/~gyurka).\n\nSupport: sander@knology.net",GOGGLES_MAJOR,GOGGLES_MINOR,GOGGLES_LEVEL,BUILD_DATE,BUILD_TIME,FOX_MAJOR,FOX_MINOR,FOX_LEVEL,getApp()->copyright),NULL,LAYOUT_FILL_X|JUSTIFY_LEFT);
-  new FXSeparator(main,SEPARATOR_LINE|LAYOUT_FILL_X);
-  new FXButton(main,"     &Close     ",NULL,&dialog,FXDialogBox::ID_CANCEL,BUTTON_DEFAULT|BUTTON_INITIAL|BUTTON_NORMAL|LAYOUT_CENTER_X);
+  FXHorizontalFrame * content=new FXHorizontalFrame(main,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0);
+  new FXImageFrame(content,img_goggles,FRAME_SUNKEN|FRAME_THICK);  
+
+  FXTabBook * tabbook=new FXTabBook(content,NULL,0,LAYOUT_FILL_X|LAYOUT_FILL_Y|LAYOUT_RIGHT,0,0,0,0,0,0,0,0);
+
+  // First item is a list
+  new FXTabItem(tabbook," &Goggles ",NULL);
+  contents=new FXVerticalFrame(tabbook,FRAME_THICK|FRAME_RAISED|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+  new FXLabel(contents,FXStringFormat("Goggles  v%d.%d.%d - %s - %s\nCopyright (C) 2002-2003 Sander Jansen. All Rights Reserved\n\nFOX Toolkit v%d.%d.%d\n%s\n\nOriginal \"Goggles\" Logo designed by Gyurka Jansen\n(http://glas.its.tudelft.nl/~gyurka).\n\nSupport: sander@knology.net",GOGGLES_MAJOR,GOGGLES_MINOR,GOGGLES_LEVEL,BUILD_DATE,BUILD_TIME,FOX_MAJOR,FOX_MINOR,FOX_LEVEL,getApp()->copyright),NULL,LAYOUT_FILL_X|JUSTIFY_LEFT);
+
+  // Second item is a file list
+  new FXTabItem(tabbook," &Ogle ",NULL);
+  contents=new FXVerticalFrame(tabbook,FRAME_THICK|FRAME_RAISED|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+  new FXLabel(contents,"A DVD player for the Solaris, Linux and BSD environments released\nunder the  GNU Public License (GPL). Ogle is developed by\na few students at Chalmers University of Technology.",NULL,LAYOUT_FILL_X|JUSTIFY_LEFT);
+
+  new FXButton(main,"     &Close     ",NULL,&dialog,FXDialogBox::ID_CANCEL,BUTTON_DEFAULT|BUTTON_INITIAL|BUTTON_NORMAL|LAYOUT_RIGHT);
   dialog.execute(PLACEMENT_SCREEN);
   return 1;
   }
